@@ -34,6 +34,6 @@
 # handle_sp(sppoly_df)
 # handle_sp(sppoly_df, group = FALSE)[[1]]
 
-handle_sp <- function(spobj, group = TRUE) {
+handle_sp <- function(spobj, group = TRUE) { # nocov start
   wicket::sp_convert(spobj, group = group)
-}
+} # nocov end
